import random
import requests

urls = [
    'https://api.producthunt.com/v1/posts?days_ago=0'
]

headers = {
    'cookie': "__cfduid=dfc05e1ccfab4b424d4eb7ba90d4816d31551874540",
    'dnt': "1",
    'authorization': "Bearer b524e2abbd9fc8fe97495eb834ad8dc2a997190901894e7f25686700e258c9ff",
    'user-agent': "Mozilla/5.0 (X11; Linux x86_64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/72.0.3626.121 Safari/537.36"
}


class ProductHunt:
    def __init__(self):
        pass

    @staticmethod
    def getHomePage():
        random.shuffle(urls)
        for i in urls:
            r = requests.get(i, headers=headers)
            try:
                return r.json()['posts']
            except ValueError:
                continue



#!/usr/bin/env python

from __future__ import print_function
import os
import requests
import platform
import subprocess
import json
import argparse
from os.path import expanduser
import signal

from producthunt import ProductHunt
from chrome import Chrome
from firefox import Firefox
from version import Version

if os.environ.get('TRAVIS') != 'true':
    import pygtk

    pygtk.require('2.0')
    import gtk

    import webbrowser

    try:
        import appindicator
    except ImportError:
        import appindicator_replacement as appindicator

    from appindicator_replacement import get_icon_filename


class HunterTrayApp:
    UPDATE_URL = "https://github.com/artiya4u/huntertray#upgrade"
    ABOUT_URL = "https://github.com/artiya4u/huntertray"

    def __init__(self, args):
        # Load the database
        home = expanduser("~")
        with open(home + '/.huntertray.json', 'a+') as content_file:
            content_file.seek(0)
            content = content_file.read()
            try:
                self.db = set(json.loads(content))
            except ValueError:
                self.db = set()

        # create an indicator applet
        self.ind = appindicator.Indicator("Hunter Tray", "hunter-tray", appindicator.CATEGORY_APPLICATION_STATUS)
        self.ind.set_status(appindicator.STATUS_ACTIVE)
        self.ind.set_icon(get_icon_filename("hunter-tray.png"))

        # create a menu
        self.menu = gtk.Menu()

        # The default state is false, and it toggles when you click on it
        self.commentState = args.comments

        # create items for the menu - refresh, quit and a separator
        menuSeparator = gtk.SeparatorMenuItem()
        menuSeparator.show()
        self.menu.append(menuSeparator)

        btnComments = gtk.CheckMenuItem("Show Comments")
        btnComments.show()
        btnComments.set_active(args.comments)
        btnComments.connect("activate", self.toggle_comments)
        self.menu.append(btnComments)

        btnAbout = gtk.MenuItem("About")
        btnAbout.show()
        btnAbout.connect("activate", self.show_about)
        self.menu.append(btnAbout)

        btnRefresh = gtk.MenuItem("Refresh")
        btnRefresh.show()
        # the last parameter is for not running the timer
        btnRefresh.connect("activate", self.refresh, True, args.chrome)
        self.menu.append(btnRefresh)

        if Version.new_available():
            btnUpdate = gtk.MenuItem("New Update Available")
            btnUpdate.show()
            btnUpdate.connect('activate', self.show_update)
            self.menu.append(btnUpdate)

        btnQuit = gtk.MenuItem("Quit")
        btnQuit.show()
        btnQuit.connect("activate", self.quit)
        self.menu.append(btnQuit)

        self.menu.show()

        self.ind.set_menu(self.menu)
        self.refresh(chrome_data_directory=args.chrome, firefox_data_directory=args.firefox)
        self.launch_analytics(args)

    def launch_analytics(self, args):
        # Now that we're all done with the boot, send a beacone home
        launch_data = vars(args)
        launch_data['version'] = Version.current()
        launch_data['platform'] = platform.linux_distribution()
        try:
            launch_data['browser'] = subprocess.check_output(["xdg-settings", "get", "default-web-browser"]).strip()
        except subprocess.CalledProcessError as e:
            launch_data['browser'] = "unknown"

    def toggle_comments(self, widget):
        """Whether comments page is opened or not"""
        self.commentState = not self.commentState

    def show_update(self, widget):
        """Handle the update button"""
        webbrowser.open(HunterTrayApp.UPDATE_URL)
        # Remove the update button once clicked
        self.menu.remove(widget)

    def show_about(self, widget):
        """Handle the about btn"""
        webbrowser.open(HunterTrayApp.ABOUT_URL)

    # ToDo: Handle keyboard interrupt properly
    def quit(self, widget, data=None):
        """ Handler for the quit button"""
        l = list(self.db)
        home = expanduser("~")

        # truncate the file
        with open(home + '/.huntertray.json', 'w+') as file:
            file.write(json.dumps(l))

        gtk.main_quit()

    def run(self):
        signal.signal(signal.SIGINT, self.quit)
        gtk.main()
        return 0

    def open(self, widget, event=None, data=None):
        """Opens the link in the web browser"""
        # We disconnect and reconnect the event in case we have
        # to set it to active and we don't want the signal to be processed
        if not widget.get_active():
            widget.disconnect(widget.signal_id)
            widget.set_active(True)
            widget.signal_id = widget.connect('activate', self.open)

        self.db.add(widget.item_id)
        webbrowser.open(widget.url)

        if self.commentState:

            webbrowser.open(widget.discussion_url)

    def add_item(self, item):
        """Adds an item to the menu"""

        i = gtk.CheckMenuItem(
            "(" + str(item['votes_count']).zfill(3) + "/" + str(item['comments_count']).zfill(3) + ")    " +
            item['name'] + ' >> ' + item['tagline'])

        visited = item['history'] or item['id'] in self.db

        i.set_active(visited)
        i.url = item['redirect_url']
        maker = 'N/A'
        if len(item['makers']) > 0:
            maker = item['makers'][0]['name']

        tooltip = "{url}\nPosted by {user} {timeago}".format(url=item['redirect_url'],
                                                             user=maker,
                                                             timeago=item['day'])
        i.set_tooltip_text(tooltip)
        i.signal_id = i.connect('activate', self.open)
        i.hn_id = item['id']
        i.item_id = item['id']
        i.discussion_url = item['discussion_url']
        self.menu.prepend(i)
        i.show()

    def refresh(self, widget=None, no_timer=False, chrome_data_directory=None, firefox_data_directory=None):

        """Refreshes the menu """
        try:
            # Create an array of 20 false to denote matches in History
            searchResults = [False] * 20
            data = list(reversed(ProductHunt.getHomePage()[0:20]))
            urls = [item['redirect_url'] for item in data]
            if chrome_data_directory:
                searchResults = self.merge_bool_array(searchResults, Chrome.search(urls, chrome_data_directory))

            if firefox_data_directory:
                searchResults = self.merge_bool_array(searchResults, Firefox.search(urls, firefox_data_directory))

            # Remove all the current stories
            for i in self.menu.get_children():
                if hasattr(i, 'url'):
                    self.menu.remove(i)

            # Add back all the refreshed news
            for index, item in enumerate(data):
                item['history'] = searchResults[index]

                self.add_item(item)
        # Catch network errors
        except requests.exceptions.RequestException as e:
            print("[+] There was an error in fetching news items")
        finally:
            # Call every 10 minutes
            if not no_timer:
                gtk.timeout_add(10 * 30 * 1000, self.refresh, widget, no_timer, chrome_data_directory)

    # Merges two boolean arrays, using OR operation against each pair
    def merge_bool_array(self, original, patch):
        for index, var in enumerate(original):
            original[index] = original[index] or patch[index]
        return original


def main():
    parser = argparse.ArgumentParser(description='ProductHunt in your System Tray')
    parser.add_argument('-v', '--version', action='version', version='0.0.1')
    parser.add_argument('-c', '--comments', dest='comments', action='store_true',
                        help="Load the PH comments link for the product as well")
    parser.add_argument('--chrome', dest='chrome',
                        help="Specify a Google Chrome Profile directory to use for matching chrome history")
    parser.add_argument('--firefox', dest='firefox',
                        help="Specify a Firefox Profile directory to use for matching firefox history")
    parser.set_defaults(comments=False)
    args = parser.parse_args()
    indicator = HunterTrayApp(args)
    indicator.run()


if __name__ == '__main__':
    main()



import requests
import pkg_resources


class Version:
    def __init__(self):
        pass

    PYPI_URL = "https://pypi.python.org/pypi/hackertray/json"

    @staticmethod
    def latest():
        res = requests.get(Version.PYPI_URL).json()
        return res['info']['version']

    @staticmethod
    def current():
        return pkg_resources.require("hackertray")[0].version

    @staticmethod
    def new_available():
        latest = Version.latest()
        current = Version.current()
        try:
            if pkg_resources.parse_version(latest) > pkg_resources.parse_version(current):
                print("[+] New version " + latest + " is available")
                return True
            else:
                return False
        except requests.exceptions.RequestException as e:
            print("[+] There was an error in trying to fetch updates")
            return False



from __future__ import print_function
import sqlite3
import shutil
import os
import sys


class Chrome:
    def __init__(self):
        pass

    HISTORY_TMP_LOCATION = '/tmp/huntertray.chrome'

    @staticmethod
    def search(urls, config_folder_path):
        Chrome.setup(config_folder_path)
        conn = sqlite3.connect(Chrome.HISTORY_TMP_LOCATION)
        db = conn.cursor()
        result = []
        for url in urls:
            db_result = db.execute('SELECT url from urls WHERE url=:url', {"url": url})
            if (db.fetchone() == None):
                result.append(False)
            else:
                result.append(True)
        os.remove(Chrome.HISTORY_TMP_LOCATION)
        return result

    @staticmethod
    def setup(config_folder_path):
        file_name = os.path.abspath(config_folder_path + '/History')
        if not os.path.isfile(file_name):
            print("ERROR: ", "Could not find Chrome history file", file=sys.stderr)
            sys.exit(1)
        shutil.copyfile(file_name, Chrome.HISTORY_TMP_LOCATION)



#=========================
#
# AppIndicator for GTK
#  drop-in replacement
#
#    Copyright 2010
#     Nathan Osman
#
#=========================

# We require PyGTK
import gtk
import gobject

# We also need os and sys
import os

from pkg_resources import resource_filename

# Types
CATEGORY_APPLICATION_STATUS = 0

# Status
STATUS_ACTIVE = 0
STATUS_ATTENTION = 1

# Locations to search for the given icon


def get_icon_filename(icon_name):
    # Determine where the icon is
    return os.path.abspath(resource_filename('huntertray.data', 'hunter-tray.png'))


# The main class
class Indicator:
    # Constructor
    def __init__(self, unknown, icon, category):
        # Store the settings
        self.inactive_icon = get_icon_filename(icon)
        self.active_icon = ""  # Blank until the user calls set_attention_icon

        # Create the status icon
        self.icon = gtk.StatusIcon()

        # Initialize to the default icon
        self.icon.set_from_file(self.inactive_icon)

        # Set the rest of the vars
        self.menu = None    # We have no menu yet

    def set_menu(self, menu):
        # Save a copy of the menu
        self.menu = menu

        # Now attach the icon's signal
        # to the menu so that it becomes displayed
        # whenever the user clicks it
        self.icon.connect("activate", self.show_menu)

    def set_status(self, status):
        # Status defines whether the active or inactive
        # icon should be displayed.
        if status == STATUS_ACTIVE:
            self.icon.set_from_file(self.inactive_icon)
        else:
            self.icon.set_from_file(self.active_icon)

    def set_label(self, label):
        self.icon.set_title(label)
        return

    def set_icon(self, icon):
        # Set the new icon
        self.icon.set_from_file(get_icon_filename(icon))

    def set_attention_icon(self, icon):
        # Set the icon filename as the attention icon
        self.active_icon = get_icon_filename(icon)

    def show_menu(self, widget):
        # Show the menu
        self.menu.popup(None, None, None, 0, 0)

        # Get the location and size of the window
        mouse_rect = self.menu.get_window().get_frame_extents()

        self.x = mouse_rect.x
        self.y = mouse_rect.y
        self.right = self.x + mouse_rect.width
        self.bottom = self.y + mouse_rect.height

        # Set a timer to poll the menu
        self.timer = gobject.timeout_add(100, self.check_mouse)

    def check_mouse(self):
        if not self.menu.get_window().is_visible():
            return

        # Now check the global mouse coords
        root = self.menu.get_screen().get_root_window()

        x, y, z = root.get_pointer()

        if x < self.x or x > self.right or y < self.y or y > self.bottom:
            self.hide_menu()
        else:
            return True

    def hide_menu(self):
        self.menu.popdown()



import sys

from setuptools import setup
from setuptools import find_packages

requirements = ['requests']
if sys.version_info < (2, 7):
    requirements.append('argparse')

setup(name='huntertray',
      version='0.0.1',
      description='ProductHunt in your System Tray',
      long_description='ProductHunt in your System Tray inspired by HackerTray',
      keywords='ProductHunt PH tray system tray icon huntertray',
      url='https://github.com/artiya4u/huntertray',
      author='Artiya Thinkumpang',
      author_email='artiya4u@gmail.com',
      license='MIT',
      packages=find_packages(),
      package_data={
          'huntertray.data': ['hunter-tray.png']
      },
      install_requires=[
          'requests>=2.2.1'
      ],
      entry_points={
          'console_scripts': ['huntertray = huntertray:main'],
      },
      zip_safe=False)
